@@ -81,10 +81,10 @@ public Q_SLOTS:
     void clear();
 
 public:
-    int columnCount(const QModelIndex &pidx = QModelIndex()) const Q_DECL_OVERRIDE;
-    int rowCount(const QModelIndex &pidx = QModelIndex()) const Q_DECL_OVERRIDE;
-    QVariant headerData(int section, Qt::Orientation o, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &pidx = QModelIndex()) const override;
+    int rowCount(const QModelIndex &pidx = QModelIndex()) const override;
+    QVariant headerData(int section, Qt::Orientation o, int role = Qt::DisplayRole) const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
 private:
     class Private;
